Registers arguments for the list subcommand on an argparse subparsers
object. When wf is non-NULL the -w/--workflow argument is omitted
because the workflow is already fixed by the calling package.
Examples
if (FALSE) { # \dontrun{
p <- argparse::ArgumentParser(prog = "test.R", python_cmd = get_python())
subp <- p$add_subparsers(dest = "subparser_name")
cli_list_add_args(subp, wf = "workflow1")
} # }