Stops with an informative message if format is not a valid output format.
Usage
nemo_assert_out_fmt(format, choices = nemo_out_formats())Stops with an informative message if format is not a valid output format.
nemo_assert_out_fmt(format, choices = nemo_out_formats())