Stops with an informative message if x is not a single non-NA character string.
Usage
nemo_assert_scalar_chr(x, arg = deparse(substitute(x)))Stops with an informative message if x is not a single non-NA character string.
nemo_assert_scalar_chr(x, arg = deparse(substitute(x)))